@@ -74,7 +74,7 @@ class Call(DateModel):
         collection_name = "_calls"
 
 
-@run_in_background
+@run_in_background(background_url=g.settings.background_tasks_url)
 @parse_objects
 def save_call(call: Call):
     try:
