@@ -1,7 +1,7 @@
 from typing import Optional
 import requests
 from functools import wraps
-
+import time
 from fastapi import Depends, APIRouter
 from fastapi.security import OAuth2PasswordBearer, OAuth2PasswordRequestForm
 from .CurrentUser import CurrentUser
@@ -18,6 +18,17 @@ from magicapi.FieldTypes import PhoneNumber
 from magicapi import g
 from magicapi.RouteClasses import MagicCallLogger
 
+import redis
+
+R = None
+if g.settings.use_doorman_redis:
+    R = redis.Redis(
+        host=g.settings.doorman_redis_endpoint,
+        port=g.settings.doorman_redis_port,
+        password=g.settings.doorman_redis_password,
+    )
+
+
 LOCATION, PROJECT_ID, DOORMAN_ID = (
     g.settings.cloud_function_location or "us-central1",
     g.settings.firebase_project_id,
@@ -117,6 +128,8 @@ def get_current_user_from_token(token: str):
         print(
             f"Current User: {current_user.uid}, name: {current_user.display_name}, phone_number: {current_user.phone_number}"
         )
+        if R:
+            R.set(current_user.uid, int(time.time()))
         return current_user
     except firebase_admin._token_gen.ExpiredIdTokenError as e:
         print("DOORMAN ERROR", e)
